@@ -129,11 +129,13 @@ def cmd_install(o):
             LOG.dbg(dotfile.prt())
         if hasattr(dotfile, 'link') and dotfile.link == LinkTypes.LINK:
             r, err = inst.link(t, dotfile.src, dotfile.dst,
-                               actionexec=pre_actions_exec)
+                               actionexec=pre_actions_exec,
+                               template=dotfile.template)
         elif hasattr(dotfile, 'link') and \
                 dotfile.link == LinkTypes.LINK_CHILDREN:
             r, err = inst.link_children(t, dotfile.src, dotfile.dst,
-                                        actionexec=pre_actions_exec)
+                                        actionexec=pre_actions_exec,
+                                        template=dotfile.template)
         else:
             src = dotfile.src
             tmp = None
@@ -147,7 +149,8 @@ def cmd_install(o):
             r, err = inst.install(t, src, dotfile.dst,
                                   actionexec=pre_actions_exec,
                                   noempty=dotfile.noempty,
-                                  ignore=ignores)
+                                  ignore=ignores,
+                                  template=dotfile.template)
             if tmp:
                 tmp = os.path.join(o.dotpath, tmp)
                 if os.path.exists(tmp):
@@ -171,6 +174,7 @@ def cmd_install(o):
                 # post-actions
                 if o.debug:
                     LOG.dbg('force post action execution ...')
+                defactions = o.install_default_actions_post
                 postactions = dotfile.get_post_actions()
                 post_actions_exec = action_executor(o, postactions, defactions,
                                                     t, post=True)
@@ -225,6 +229,9 @@ def cmd_compare(o, tmp):
     comp = Comparator(diff_cmd=o.diff_command, debug=o.debug)
 
     for dotfile in selected:
+        if not dotfile.src and not dotfile.dst:
+            # ignore fake dotfile
+            continue
         # add dotfile variables
         t.restore_vars(tvars)
         newvars = dotfile.get_dotfile_variables()
@@ -263,7 +270,8 @@ def cmd_compare(o, tmp):
             continue
 
         # install dotfile to temporary dir and compare
-        ret, err, insttmp = inst.install_to_temp(t, tmp, src, dotfile.dst)
+        ret, err, insttmp = inst.install_to_temp(t, tmp, src, dotfile.dst,
+                                                 template=dotfile.template)
         if not ret:
             # failed to install to tmp
             line = '=> compare {}: error'
@@ -576,7 +584,21 @@ def cmd_remove(o):
 
             # remove dotfile from dotpath
             dtpath = os.path.join(o.dotpath, dotfile.src)
-            remove(dtpath)
+            try:
+                remove(dtpath)
+            except OSError:
+                # did not exist
+                pass
+            # remove empty directory
+            parent = os.path.dirname(dtpath)
+            # remove any empty parent up to dotpath
+            while parent != o.dotpath:
+                if os.path.isdir(parent) and not os.listdir(parent):
+                    msg = 'Remove empty dir \"{}\"'.format(parent)
+                    if o.safe and not LOG.ask(msg):
+                        break
+                    remove(parent)
+                parent = os.path.dirname(parent)
             removed.append(dotfile.key)
 
     if o.dry:
@@ -736,9 +758,14 @@ def main():
         LOG.err('interrupted')
         ret = False
 
+    if o.debug:
+        LOG.dbg('done executing command')
+
     if ret and o.conf.save():
         LOG.log('config file updated')
 
+    if o.debug:
+        LOG.dbg('return {}'.format(ret))
     return ret
 
 
